California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| CAMPAIGN FINANCE: Candidates & Elected Officials
Choose a Listing: Certified Election Candidates Incumbent Elected State Officials Candidates and Elected Officials By Name Who filed a Statement of Intention to run for What State Office? (Filers may not have qualified for the ballot) CalPERS and CalSTRS Candidate Filings, Scanned Images |
Go to Section:
| Statewide Candidates
| State Senate Candidates
| State Assembly Candidates
Choose an Election: 2022 PRIMARY 2021 SPECIAL ELECTION (ASSEMBLY 54) Prior Elections 2021 SPECIAL ELECTION (ASSEMBLY 79) 2021 SPECIAL ELECTION (STATE SENATE 30) 2020 GENERAL 2020 SPECIAL RUNOFF (STATE SENATE 28) 2020 PRIMARY 2020 SPECIAL ELECTION (STATE SENATE 28) 2019 SPECIAL RUNOFF (ASSEMBLY 01) 2019 SPECIAL ELECTION (ASSEMBLY 01) 2019 SPECIAL RUNOFF (STATE SENATE 01) 2019 SPECIAL RUNOFF (STATE SENATE 33) 2019 SPECIAL ELECTION (STATE SENATE 01) 2019 SPECIAL ELECTION (STATE SENATE 33) 2018 GENERAL 2018 SPECIAL RUNOFF (STATE SENATE 32) 2018 PRIMARY 2018 SPECIAL ELECTION (STATE SENATE 32) 2018 SPECIAL ELECTION (STATE SENATE 29) 2018 SPECIAL RUNOFF (ASSEMBLY 45) 2018 SPECIAL RUNOFF (ASSEMBLY 39) 2018 SPECIAL ELECTION (ASSEMBLY 45) 2018 SPECIAL ELECTION (ASSEMBLY 54) 2018 SPECIAL ELECTION (ASSEMBLY 39) 2017 SPECIAL RUNOFF (ASSEMBLY 51) 2017 SPECIAL ELECTION (ASSEMBLY 51) 2016 GENERAL 2016 PRIMARY 2016 SPECIAL ELECTION (ASSEMBLY 31) 2015 SPECIAL RUNOFF (STATE SENATE 07) 2015 SPECIAL ELECTION (STATE SENATE 37) 2015 SPECIAL ELECTION (STATE SENATE 21) 2015 SPECIAL ELECTION (STATE SENATE 07) 2014 SPECIAL ELECTION (STATE SENATE 35) 2014 GENERAL 2014 PRIMARY 2014 SPECIAL ELECTION (STATE SENATE 23) 2013 SPECIAL ELECTION (ASSEMBLY 54) 2013 SPECIAL RUNOFF (ASSEMBLY 45) 2013 SPECIAL RUNOFF (ASSEMBLY 52) 2013 SPECIAL ELECTION (STATE SENATE 26) 2013 SPECIAL ELECTION (ASSEMBLY 45) 2013 SPECIAL ELECTION (ASSEMBLY 52) 2013 SPECIAL RUNOFF (STATE SENATE 16) 2013 SPECIAL ELECTION (ASSEMBLY 80) 2013 SPECIAL ELECTION (STATE SENATE 16) 2013 SPECIAL RUNOFF (STATE SENATE 32) 2013 SPECIAL ELECTION (STATE SENATE 40) 2013 SPECIAL ELECTION (STATE SENATE 32) 2013 SPECIAL ELECTION (STATE SENATE 04) 2012 GENERAL 2012 SPECIAL ELECTION (STATE SENATE 04) 2012 PRIMARY 2011 SPECIAL RUNOFF (ASSEMBLY 04) 2011 SPECIAL ELECTION (ASSEMBLY 04) 2011 SPECIAL ELECTION (STATE SENATE 17) 2011 SPECIAL ELECTION (STATE SENATE 28) 2011 SPECIAL RUNOFF (STATE SENATE 01) 2010 GENERAL 2010 SPECIAL ELECTION (STATE SENATE 01) 2010 SPECIAL RUNOFF (STATE SENATE 15) 2010 SPECIAL ELECTION (STATE SENATE 15) 2010 PRIMARY 2010 SPECIAL RUNOFF (STATE SENATE 37) 2010 SPECIAL RUNOFF (ASSEMBLY 43) 2010 SPECIAL ELECTION (STATE SENATE 37) 2010 SPECIAL ELECTION (ASSEMBLY 43) 2010 SPECIAL RUNOFF (ASSEMBLY 72) 2009 SPECIAL ELECTION (ASSEMBLY 72) 2009 SPECIAL ELECTION (ASSEMBLY 51) 2009 SPECIAL RUNOFF (STATE SENATE 26) 2009 SPECIAL ELECTION (STATE SENATE 26) 2008 GENERAL 2008 PRIMARY 2008 RECALL (STATE SENATE 12) 2008 SPECIAL RUNOFF (ASSEMBLY 55) 2007 SPECIAL ELECTION (ASSEMBLY 55) 2007 SPECIAL ELECTION (ASSEMBLY 39) 2006 GENERAL 2006 PRIMARY 2006 SPECIAL RUNOFF (STATE SENATE 35) 2006 SPECIAL ELECTION (STATE SENATE 35) 2005 SPECIAL ELECTION (ASSEMBLY 53) 2004 GENERAL 2004 PRIMARY 2003 SPECIAL ELECTION (GOVERNOR) 2002 GENERAL 2002 PRIMARY 2001 SPECIAL ELECTION (ASSEMBLY 49) 2001 SPECIAL RUNOFF (ASSEMBLY 65) 2001 SPECIAL ELECTION (STATE SENATE 24) 2001 SPECIAL ELECTION (ASSEMBLY 65) 2000 GENERAL 2000 PRIMARY
Also check Late Contribution filings. These reports are independent of the comprehensive disclosure reports that are linked here until semi-annual filings are submitted.
STATEWIDE OFFICES
GOVERNOR
ALVAREZ, CARLOS BROWN, EDMUND G. (JERRY) NIGHTINGALE, CHELENE H. OGDEN, DALE F. WELLS, LAURA WHITMAN, MARGARET C.
| LIEUTENANT GOVERNOR
BROWN, PAMELA J. CASTILLO, JAMES R. KING, JIM MALDONADO, ABEL NEWSOM, GAVIN WEBER, C.T.
SECRETARY OF STATE
BOWEN, DEBRA CABRAL, MARYLOU DUNN, DAMON J. MENASCHE, ANN E. SHORT, MERTON D. TOBIN, CHRISTINA M.
| CONTROLLER
BELIZ, LAWRENCE G. CHIANG, JOHN FAVOR, ANDREW H. FRANKEL, ROSS D. MARTINEZ, KAREN LOIS STRICKLAND, TONY
TREASURER
CRITTENDEN, CHARLES LAUTEN, ROBERT E. LOCKYER, BILL REIGER, DEBRA L. TEYSSIER, EDWARD M. WALTERS, MIMI
| ATTORNEY GENERAL
ALLEN, PETER V. COOLEY, STEVE EVANS, ROBERT J. HANNAN, TIMOTHY J. HARRIS, KAMALA D. TEMPLIN, DIANE BEALL
SUPERINTENDENT OF PUBLIC INSTRUCTION
ACEVES, LARRY TORLAKSON, TOM
| INSURANCE COMMISSIONER
BALDERSTON, WILLIAM J. BRONSTEIN, RICHARD S. JONES, DAVE PADILLA, DINA J. PEDERSEN, CLAYTON E. VILLINES, MICHAEL N.
BOARD OF EQUALIZATION
MEMBER BOARD OF EQUALIZATION 01
BORG, SHERILL L. SCOTT, KEVIN R. WATSON, KENNITA L. YEE, BETTY T.
| MEMBER BOARD OF EQUALIZATION 02
MICHLIN, WILLARD D. MITCHELL-SAWYER, TOBY D. PARKER, CHRIS R. RUNNER, GEORGE C.
MEMBER BOARD OF EQUALIZATION 03
DIXON, JERRY L. FINLEY, MARY LOU HEISING-CHRISTIAN, MARY LUSSENHEIDE, TERRI L. STEEL, MICHELLE
| MEMBER BOARD OF EQUALIZATION 04
DE BAETS, PETER D. HOFFMAN, SHAWN HORTON, JEROME E. LAWRENCE, NANCY
SENATE DISTRICTS
STATE SENATE 02
EVANS, NOREEN M. WIESNER, LAWRENCE R.
| STATE SENATE 04
GILL, LATHE SHELDON LA MALFA, DOUG
STATE SENATE 06
HYLAND, LANRIC STEINBERG, DARRELL TORNO, STEVE WEILAND, MARCEL C.
| STATE SENATE 08
PARK, DOO YEE, LELAND Y.
STATE SENATE 10
CHOU, IVAN C. CORBETT, ELLEN MAFFIT, ROBERT B.
| STATE SENATE 12
CABALLERO, ANNA CANNELLA, ANTHONY JOSEPH
STATE SENATE 14
BERRYHILL, TOM JOHNSON, LARRY
| STATE SENATE 16
RUBIO, MICHAEL J. THIESEN, TIMOTHY A.
STATE SENATE 18
FULLER, JEAN POPE, CARTER N.
| STATE SENATE 20
EVANS, KATHLEEN S. GALYSH, ADRIAN B. PADILLA, ALEX
STATE SENATE 22
DE LEON, KEVIN
| STATE SENATE 24
HERNANDEZ, EDWARD P. MORRISON, WILLIAM M.
STATE SENATE 26
HENDERSON, CINDY VARELA PRICE, CURREN D. SHIFREN, NACHUM WEBER, JR., ROBERT G.
| STATE SENATE 28
OROPEZA, JENNY RUSKIN, DAVID STAMMREICH, JOHN S.
STATE SENATE 30
CALDERON, RONALD WILLIS, WARREN P.
| STATE SENATE 32
DE VRIES, EARL MC LEOD, GLORIA NEGRETE
STATE SENATE 34
CORREA, LOU KRING, LUCILLE
| STATE SENATE 36
ANDERSON, JOEL C. CLAY, PAUL METTI, MICHAEL S.
STATE SENATE 38
JONES, GILA STONE, KRISTI WYLAND, MARK B.
| STATE SENATE 40
HENDRY, BRIAN J. VARGAS, JUAN C.
ASSEMBLY DISTRICTS
ASSEMBLY 01
BROOKS, KAREN CHESBRO, WESLEY
| ASSEMBLY 02
NIELSEN, JIM
ASSEMBLY 03
BRYANT, GARY C. HARRINGTON, MICHAEL "MICKEY" LOGUE, DANIEL R.
| ASSEMBLY 04
CAMPANALE, DENNIS J. FREDERICK, DANIEL D. GAINES, EDWARD T
ASSEMBLY 05
MARTINEZ, ELIZABETH S. PAN, RICHARD PUGNO, ANDREW
| ASSEMBLY 06
HUFFMAN, JARED STEPHENS, ROBERT L.
ASSEMBLY 07
ALLEN, MICHAEL J. GENTRY, DORIS L. MOORE, KATHRYN N.
| ASSEMBLY 08
CONNOR, MICHELLE P. YAMADA, MARIKO M.
ASSEMBLY 09
COSTA, DANIEL A. DICKINSON, ROGER REDDING, RICK D.
| ASSEMBLY 10
BONSER, JANICE M. HUBER, ALYSON SIEGLOCK, JACK A. TROYER, ALBERT
ASSEMBLY 11
BONILLA, SUSAN CRAVEN, JULIE
| ASSEMBLY 12
FAUSTINO, ALFONSO S. MA, FIONA
ASSEMBLY 13
AMMIANO, TOM PETER, LAURA A.
| ASSEMBLY 14
HATCHER, RYAN J. SKINNER, NANCY
ASSEMBLY 15
BUCHANAN, JOAN WILSON, ABRAM
| ASSEMBLY 16
FAISON, JAMES RINGER, LISA D. SWANSON, SANDRE
ASSEMBLY 17
GALGIANI, CATHLEEN MOBLEY JR., JACK M.
| ASSEMBLY 18
HAVIG, MICHAEL HAYASHI, MARY
ASSEMBLY 19
HILL, JERRY A. TUTIN, GARY WAISMAN, ALBERTO A.
| ASSEMBLY 20
SHAHAB, ADNAN I. WIECKOWSKI, ROBERT
ASSEMBLY 21
BELL, JR., RAYMOND M. CONLON, GREG GORDON, RICHARD S.
| ASSEMBLY 22
CAMPBELL, TIMOTHY J. (T.J.) FONG, PAUL HICKOK, ERIC
ASSEMBLY 23
CAMPOS, NORA ELIA SAINI, ATUL
| ASSEMBLY 24
BEALL, JIM CHANDLER, ROBERT L.
ASSEMBLY 25
OLSEN, KRISTIN M.
| ASSEMBLY 26
BERRYHILL, WILLIAM R. WEINTZ, TIM P.
ASSEMBLY 27
BLACK, LINDA "ELLIE" MONNING, WILLIAM W.
| ASSEMBLY 28
ALEJO, LUIS BERNOSKY, ROBERT E.
ASSEMBLY 29
ESSWEIN, MICHAEL J. HALDERMAN, LINDA F.
| ASSEMBLY 30
FLOREZ, FRAN VALADAO, DAVID G.
ASSEMBLY 31
PEREA, HENRY T. SHOEMAKER, BRANDON K.
| ASSEMBLY 32
GROVE, SHANNON SPOHN-GROSS, HOLLY
ASSEMBLY 33
ACHADJIAN, KHATCHIK POLSON, PAUL K. ZACARIAS, HILDA
| ASSEMBLY 34
CASTRO, ESMERALDA CONWAY, CONNIE
ASSEMBLY 35
STOKER, MIKE WILLIAMS, DAS
| ASSEMBLY 36
JONES, LINDA K. KNIGHT, STEVE
ASSEMBLY 37
GORELL, JEFF MASRY, FERIAL
| ASSEMBLY 38
CHRISTENSEN, PEGGY L. SHAW, DIANA SMYTH, CAMERON
ASSEMBLY 39
FUENTES, FELIPE LINDBLAD, JOHN P. (JACK)
| ASSEMBLY 40
BLUMENFIELD, BOB DE YOUNG, DENNIS
ASSEMBLY 41
BROWNLEY, JULIA RATHBUN, TERRENCE L.
| ASSEMBLY 42
FEUER, MICHAEL NELSON TOMAN, MARY A.
ASSEMBLY 43
GATTO, MIKE RAMANI, SUNDER
| ASSEMBLY 44
DAY, ALVARO G. KOLLIN, EYTAN PORTANTINO, ANTHONY
ASSEMBLY 45
CEDILLO, GILBERT OLIVOS, SUZANNE
| ASSEMBLY 46
PEREZ, JOHN A.
ASSEMBLY 47
CAGE, LADY MC GARY, SEAN P. MITCHELL, HOLLY J.
| ASSEMBLY 48
DAVIS, MIKE
ASSEMBLY 49
ENG, MICHAEL TAYLOR, BRADLEY J.
| ASSEMBLY 50
LARA, RICARDO MILLER, GLADYS O.
ASSEMBLY 51
BRADFORD, STEVEN SANTIAGO, CYNTHIA
| ASSEMBLY 52
HALL, ISADORE PATRICK, GWEN (BATISTE)
ASSEMBLY 53
BUTLER, BETSY GREEN, LISA A. MINTZ, NATHAN M. MUSULIN, ETHAN M.
| ASSEMBLY 54
FLORES-GIBSON, MARTHA LOWENTHAL, BONNIE
ASSEMBLY 55
FURUTANI, WARREN SALABAJ, CHRISTOPHER J.
| ASSEMBLY 56
BESTWICK, HENRY J. MENDOZA, TONY
ASSEMBLY 57
GUTIERREZ, BRIAN A. HERNANDEZ, ROGER
| ASSEMBLY 58
CALDERON, CHARLES M. MAY, GARRETT M.
ASSEMBLY 59
DONNELLY, TIM GOSNEY, ROBERT D. TYLER, TONY WOODS, DARCEL
| ASSEMBLY 60
HAGMAN, CURT
ASSEMBLY 61
MOORS, RAYMOND KENNETH TORRES, NORMA
| ASSEMBLY 62
CARTER, WILMER AMINA ENSLEY, JEANE M.
ASSEMBLY 63
MORRELL, MIKE WICKMAN, RENEA
| ASSEMBLY 64
MEDINA, JOSE J. NESTANDE, BRIAN
ASSEMBLY 65
COOK, PAUL J. WOOD, CARL W.
| ASSEMBLY 66
DYE, DOUGLAS JEFFRIES, KEVIN D.
ASSEMBLY 67
FREEMAN, ROSALIND A. SILVA, JAMES W.
| ASSEMBLY 68
MANSOOR, ALLAN R. NGUYEN, PHU
ASSEMBLY 69
HAMMOND, ROBERT MORRIS SOLORIO, JOSE
| ASSEMBLY 70
FOX, MELISSA THARP, DEBORAH WAGNER, DON
ASSEMBLY 71
KEPHART, GARY R. MILLER, JEFF
| ASSEMBLY 72
NORBY, CHRIS RANDS, JANE A. UBALLE, ESIQUIO
ASSEMBLY 73
HARKEY, DIANE JONES, JUDITH E.
| ASSEMBLY 74
CRAWFORD, CRYSTAL GARRICK, MARTIN W. KING, PAUL
ASSEMBLY 75
CHADWICK, CHRISTOPHER A. FLETCHER, NATHAN B. GARVER, PAUL
| ASSEMBLY 76
ATKINS, TONI G. BAEHR, DANIEL H. DENNEY, RALPH
ASSEMBLY 77
BELITZ, RICHARD G. HANSON, MARK N. JONES, BRIAN W.
| ASSEMBLY 78
BLOCK, MARTY J. POWELL, RICK L.
ASSEMBLY 79
HUESO, BEN ROACH, DERRICK
| ASSEMBLY 80
PEREZ, V. MANUEL SANCHEZ, STEVE